==> actions-recorder-0.0.1.tgz: package/lib/panel/controller.js <==
"use strict";

var React = require("react"),
    Immutable = require("immutable");

var RecordItem = React.createFactory(require("./record-item"));
var div = React.createFactory("div");
module.exports = React.createClass({
  displayName: "actions-recorder-controller",
  propTypes: {
    records: React.PropTypes.instanceOf(Immutable.List),
    pointer: React.PropTypes.number.isRequired,
    onCommit: React.PropTypes.func.isRequired,
    onReset: React.PropTypes.func.isRequired,
    onPeek: React.PropTypes.func.isRequired,
    onDiscard: React.PropTypes.func.isRequired
  },
  render: function render() {
    var _this = this;

    return div({
      className: "actions-recorder-controller"
    }, div({
      className: "recorder-monitor",
      style: {
        paddingBottom: innerHeight - 50,
        height: innerHeight - 50
      }
    }, this.props.records.map(function (record, index) {
      var onClick = function onClick() {
        return _this.props.onPeek(index);
      };

      return RecordItem({
        onClick: onClick,
        record: record,
        key: index,
        index: index,
        isPointer: _this.props.pointer === index,
        onPeek: _this.props.onPeek
      });
    })), div({
      className: "recorder-footer"
    }, div({
      className: "button is-attract",
      onClick: this.props.onCommit
    }, "Commit"), div({
      className: "button is-danger",
      onClick: this.props.onDiscard
    }, "Discard"), div({
      className: "button is-danger",
      onClick: this.props.onReset
    }, "Reset")));
  }
});

==> actions-recorder-0.0.2.tgz: package/lib/panel/controller.js <==
"use strict";

var React = require("react"),
    Immutable = require("immutable");

var RecordItem = React.createFactory(require("./record-item"));
var div = React.createFactory("div");
module.exports = React.createClass({
  displayName: "actions-recorder-controller",
  propTypes: {
    records: React.PropTypes.instanceOf(Immutable.List),
    pointer: React.PropTypes.number.isRequired,
    isTravelling: React.PropTypes.bool.isRequired,
    onCommit: React.PropTypes.func.isRequired,
    onSwitch: React.PropTypes.func.isRequired,
    onReset: React.PropTypes.func.isRequired,
    onPeek: React.PropTypes.func.isRequired,
    onDiscard: React.PropTypes.func.isRequired
  },
  render: function render() {
    var _this = this;

    return div({
      className: "actions-recorder-controller"
    }, div({
      className: "recorder-monitor",
      style: {
        paddingBottom: innerHeight - 50,
        height: innerHeight - 50
      }
    }, this.props.records.map(function (record, index) {
      var onClick = function onClick() {
        return _this.props.onPeek(index);
      };

      return RecordItem({
        onClick: onClick,
        record: record,
        key: index,
        index: index,
        isPointer: _this.props.isTravelling && _this.props.pointer === index,
        onPeek: _this.props.onPeek
      });
    })), div({
      className: "recorder-footer"
    }, div({
      className: "button is-attract",
      onClick: this.props.onCommit
    }, "Commit"), div({
      className: "button is-attract",
      onClick: this.props.onSwitch
    }, this.props.isTravelling ? "Back" : "Travel"), div({
      className: "button is-danger",
      onClick: this.props.onDiscard
    }, "Discard"), div({
      className: "button is-danger",
      onClick: this.props.onReset
    }, "Reset")));
  }
});
